==> tur-all-trial_1.0.tar.gz: tur-all-trial.sh <==
#!/bin/bash
##################################################################
# Tur-All Trial 1.0  ( http://www.grandis.nu/glftpd )            #
# This script, together with tur-all-trial.tcl, can be used to   #
# check how your users is doing in either a weekly or montly     # 
# trial using !passed <user> from irc.                           #
# It supports up to 9 stat sections. If it finds more then one   #
# it will simply add them all up.                                #
#                                                                #
# Unlike the Tur-Trial script, in Tur-All Trial, everyone on the #
# site is on trial. If you have a weekly or monthly ratio that   #
# must be uploaded for instance, this script will show how users #
# are doing.                                                     #
#                                                                #
# You can exclude groups directly in this script and it          #
# can also look in some folders for group folders. Like if       #
# you have a /site/GROUPS folder, where all the groups have a    #
# pre folder of their own, it can use that to exclude affils,    #
# as long as the foldername is exactly the same as the groupname.#
# You can add multiple folders here if you have your affils      #
# spread out, like;                                              #
# "/glftpd/site/DIVX/GROUPS /glftpd/site/incoming/SVCD/GROUPS"   #
#                                                                #
# This script will not delete any users. Thats up to you.        #
# Get the MonthUpAll script if you want a log of everyone and    #
# how much they upped.                                           #
#                                                                #
# Installation:                                                  #
# You need some standard binaries, like grep, cat, expr & tr.    #
#                                                                #
# Put tur-all-trial.sh in glftpd's bin dir, and                  #
# tur-all-trial.tcl in your bots scripts dir. Load the tcl in    #
# your bots conf file. Rehash the bot.                           #
# If you have the normal Tur-Trial running as well, change the   #
# trigger to something other then !passed in tur-all-trial.tcl   #
#                                                                #
# Make sure tur-all-trial.sh is executable by the user           #
# who runs the bot.                                              #
#                                                                #
# Set up the parameters below and try to run tur-all-trial.sh    #
# from shell. If it works from shell, it should work from        #
# the bot.                                                       #
#                                                                #
# If you wish to change the outputs, you can use $BOLD to start  #
# and stop the text from being displayed in bold.                #
#                                                                #
##################################################################
# Changelog:                                                     #
# 1.0 : Initial release.                                         #
##################################################################
# Settings:

USERSLOCATION=/glftpd/ftp-data/users                        # Userfiles location.
LIMIT="2000"                                                # MB to pass the trial.
DURATION="M"                                                # W = weekly. M = monthly trial.
BOLD=""                                                   # Dont change this one :)
SITENAME="$BOLD-xXx-$BOLD"                                  # Name of site (replace the xXx).
SHOWLIMIT="TRUE"                                            # Show the limit in output? TRUE/FALSE
AFFILS="Friends SiTEOPS STAFF"                              # Groups not on trial. Space Separated.
AFFILSFOLDER="/glftpd/site/GROUPS /glftpd/site/DIVX/GROUPS" # See instructions above. Space Separated. "" = disable.
EXCLUDE="default.user glftpd"                               # These users cant be checked. Space delimited.
EXCLUDEDTEXT="$1 cant be checked"                           # Text to show incase user is excluded. 
                                                            # Leave empty to not say anything.

###############################################################################
# No changes should be needed under here, unless you want to change some text #
###############################################################################

## Check some stuff.

if [ -e "$USERSLOCATION" ]; then
  ok=yes
else
  echo "Cant find $USERSLOCATION. Check settings."
  exit 1
fi

for verifyfolder in `echo $AFFILSFOLDER`; do
  if [ -e "$verifyfolder" ]; then
    ok=yes
  else
    echo "Can not find $verifyfolder. Check AFFILSFOLDER settings"
    exit 1
  fi
done

## If no argument is given after trigger:
if [ "$1" = "" ]; then
  echo "$BOLD$SITENAME$BOLD Specify a user to check too."
  exit 0
fi

## Check if the user really exists.
if [ -e $USERSLOCATION/$1 ]; then
  ok=yes
else
  echo "$SITENAME User $BOLD$1$BOLD does not exists on $SITENAME"
  exit 0
fi

## Is the user excluded?
EXCLUDED=""
EXCLUDED="$( echo "$EXCLUDE" | grep -w $1 )"
if [ "$EXCLUDED" != "" ]; then
  if [ "$EXCLUDEDTEXT" = "" ]; then
    exit 0
  else
    echo "$SITENAME $EXCLUDEDTEXT"
    exit 0
  fi
fi  

## Do we want weekly or monthly trials?
case $DURATION in
 W) 
   DUR="WKUP"
   DURNAME="week"
   ;;
 M)
   DUR="MONTHUP"
   DURNAME="month"
   ;;
 *)
   echo "Duration not set right. Either W or M"
   exit 0
   ;;
esac

if [ "$AFFILSFOLDER" != "" ]; then
  for folder in `echo $AFFILSFOLDER`; do
    cd $folder
    for affils in `ls`; do
      GAFFILS="$affils $GAFFILS"
    done
  done
  if [ "$GAFFILS" = "" ]; then
    GAFFILS="$AFFILS"
  else
    GAFFILS="$AFFILS $GAFFILS"
  fi
else
  GAFFILS="$AFFILS"
fi

VERIFY=""
for g in `cat $USERSLOCATION/$1 | grep -w GROUP`; do
  if [ "$EXCLUDED" != "YES" ]; then
    VERIFY="$( echo $GAFFILS | grep -w $g )"
    if [ "$VERIFY" != "" ]; then
      MSG="$BOLD$1$BOLD is in affiliated group $BOLD$g$BOLD. Had that not been the case"
      EXCLUDED="YES"
    fi
  fi
done

if [ "$EXCLUDED" != "YES" ]; then
  MSG="$BOLD$1$BOLD"
fi

## How much did the user upload this period? 
UP="$( cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $3}')"
if [ "$UP" = "" ]; then
  UP="0"
fi

## Check for other stat sections.
UP2="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $6}')"
if [ "$UP2" != "" ]; then
  UP3="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $9}')"
  if [ "$UP3" != "" ]; then
    UP4="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $12}')"
    if [ "$UP4" != "" ]; then
      UP5="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $15}')"
      if [ "$UP5" != "" ]; then
        UP6="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $18}')"
        if [ "$UP6" != "" ]; then
          UP7="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $21}')"
          if [ "$UP7" != "" ]; then
            UP8="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $24}')"
            if [ "$UP8" != "" ]; then
              UP9="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $27}')"
              if [ "$UP9" != "" ]; then
                UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" \+ "$UP5" \+ "$UP6" \+ "$UP7" \+ "$UP8" \+ "$UP9" )"
              else
                UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" \+ "$UP5" \+ "$UP6" \+ "$UP7" \+ "$UP8" )"
              fi
            else
              UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" \+ "$UP5" \+ "$UP6" \+ "$UP7" )"
            fi
          else
            UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" \+ "$UP5" \+ "$UP6" )"
          fi
        else
          UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" \+ "$UP5" )"
        fi
      else
        UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" )"
      fi
    else
      UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" )"
    fi
  else
    UP="$( expr "$UP" \+ "$UP2" )"
  fi
fi

## Split the uploaded number with 1024 to get MB.
UP="$( expr $UP \/ 1024 )"

## Is the user over the limit?
if [ "$UP" -gt "$LIMIT" ]; then
  PASSED="YES"
else
  PASSED="NO"
fi

## Calculate how much under or over the limit the user is.
RATIO="$( expr $UP \- $LIMIT )"

## If the number is negative, remove the - 
RATIO="$( echo $RATIO | tr -d "-")"

## Do we want to show the limit in output?
if [ "$SHOWLIMIT" = "TRUE" ]; then
  SHOWL=" ($LIMIT MB/$DURNAME)"
else
  SHOWL=""
fi

## Say what we want to say, depending on if the user passed the limit or not, and if hes on trial.
case $PASSED in
  YES)
    if [ "$EXCLUDED" = "YES" ]; then
      echo "$SITENAME $MSG, the limit$SHOWL would have been passed with $BOLD$RATIO MB$BOLD to spare."
      exit 0
    else
      echo "$SITENAME $MSG has passed the limit$SHOWL with $BOLD$RATIO$BOLD to spare."
      exit 0
    fi
    ;;
  NO)
    if [ "$EXCLUDED" = "YES" ]; then
      echo "$SITENAME $MSG, then $1 would be missing $BOLD$RATIO MB$BOLD to pass$SHOWL."
      exit 0
    else
      echo "$SITENAME $MSG is missing $BOLD$RATIO MB$BOLD to pass$SHOWL."
      exit 0
    fi
    ;;
  *)
    echo "Error in script. User neither passed or failed trial."
    exit 1
    ;;
esac

exit 0

==> tur-all-trial_1.0.1.tar.gz: tur-all-trial.sh <==
#!/bin/bash
##################################################################
# Tur-All Trial 1.0.1( http://www.grandis.nu/glftpd )            #
# This script, together with tur-all-trial.tcl, can be used to   #
# check how your users is doing in either a weekly or montly     # 
# trial using !passed <user> from irc.                           #
# It supports up to 9 stat sections. If it finds more then one   #
# it will simply add them all up.                                #
#                                                                #
# Unlike the Tur-Trial script, in Tur-All Trial, everyone on the #
# site is on trial. If you have a weekly or monthly ratio that   #
# must be uploaded for instance, this script will show how users #
# are doing.                                                     #
#                                                                #
# You can exclude groups directly in this script and it          #
# can also look in some folders for group folders. Like if       #
# you have a /site/GROUPS folder, where all the groups have a    #
# pre folder of their own, it can use that to exclude affils,    #
# as long as the foldername is exactly the same as the groupname.#
# You can add multiple folders here if you have your affils      #
# spread out, like;                                              #
# "/glftpd/site/DIVX/GROUPS /glftpd/site/incoming/SVCD/GROUPS"   #
#                                                                #
# This script will not delete any users. Thats up to you.        #
# Get the MonthUpAll script if you want a log of everyone and    #
# how much they upped. MonthUpAll can also delete the users for  #
# you if you are brave enough.                                   #
#                                                                #
# Installation:                                                  #
# You need some standard binaries, like grep, cat, expr & tr.    #
#                                                                #
# Put tur-all-trial.sh in glftpd's bin dir, and                  #
# tur-all-trial.tcl in your bots scripts dir. Load the tcl in    #
# your bots conf file. Rehash the bot.                           #
# If you have the normal Tur-Trial running as well, change the   #
# trigger to something other then !passed in tur-all-trial.tcl   #
#                                                                #
# Make sure tur-all-trial.sh is executable by the user           #
# who runs the bot.                                              #
#                                                                #
# Set up the parameters below and try to run tur-all-trial.sh    #
# from shell. If it works from shell, it should work from        #
# the bot.                                                       #
#                                                                #
# If you wish to change the outputs, you can use $BOLD to start  #
# and stop the text from being displayed in bold.                #
#                                                                #
##################################################################
# Changelog:                                                     #
# 1.0.1 : Fix: If the user passed, it did not say MB after the   #
#              amount he passed with.                            #
# 1.0   : Initial release.                                       #
##################################################################
# Settings:

USERSLOCATION=/glftpd/ftp-data/users                        # Userfiles location.
LIMIT="2000"                                                # MB to pass the trial.
DURATION="M"                                                # W = weekly. M = monthly trial.
BOLD="^B"                                                   # Dont change this one :)
SITENAME="$BOLD-xXx-$BOLD"                                  # Name of site (replace the xXx).
SHOWLIMIT="TRUE"                                            # Show the limit in output? TRUE/FALSE
AFFILS="Friends SiTEOPS STAFF"                              # Groups not on trial. Space Separated.
AFFILSFOLDER="/glftpd/site/GROUPS /glftpd/site/DIVX/GROUPS" # See instructions above. Space Separated. "" = disable.
EXCLUDE="default.user glftpd"                               # These users cant be checked. Space delimited.
EXCLUDEDTEXT="$1 cant be checked"                           # Text to show incase user is excluded.
                                                            # Leave empty to not say anything.

###############################################################################
# No changes should be needed under here, unless you want to change some text #
###############################################################################

## Check some stuff.

if [ -e "$USERSLOCATION" ]; then
  ok=yes
else
  echo "Cant find $USERSLOCATION. Check settings."
  exit 1
fi

for verifyfolder in `echo $AFFILSFOLDER`; do
  if [ -e "$verifyfolder" ]; then
    ok=yes
  else
    echo "Can not find $verifyfolder. Check AFFILSFOLDER settings"
    exit 1
  fi
done

## If no argument is given after trigger:
if [ "$1" = "" ]; then
  echo "$BOLD$SITENAME$BOLD Specify a user to check too."
  exit 0
fi

## Check if the user really exists.
if [ -e $USERSLOCATION/$1 ]; then
  ok=yes
else
  echo "$SITENAME User $BOLD$1$BOLD does not exists on $SITENAME"
  exit 0
fi

## Is the user excluded?
EXCLUDED=""
EXCLUDED="$( echo "$EXCLUDE" | grep -w $1 )"
if [ "$EXCLUDED" != "" ]; then
  if [ "$EXCLUDEDTEXT" = "" ]; then
    exit 0
  else
    echo "$SITENAME $EXCLUDEDTEXT"
    exit 0
  fi
fi  

## Do we want weekly or monthly trials?
case $DURATION in
 W) 
   DUR="WKUP"
   DURNAME="week"
   ;;
 M)
   DUR="MONTHUP"
   DURNAME="month"
   ;;
 *)
   echo "Duration not set right. Either W or M"
   exit 0
   ;;
esac

if [ "$AFFILSFOLDER" != "" ]; then
  for folder in `echo $AFFILSFOLDER`; do
    cd $folder
    for affils in `ls`; do
      GAFFILS="$affils $GAFFILS"
    done
  done
  if [ "$GAFFILS" = "" ]; then
    GAFFILS="$AFFILS"
  else
    GAFFILS="$AFFILS $GAFFILS"
  fi
else
  GAFFILS="$AFFILS"
fi

VERIFY=""
for g in `cat $USERSLOCATION/$1 | grep -w GROUP`; do
  if [ "$EXCLUDED" != "YES" ]; then
    VERIFY="$( echo $GAFFILS | grep -w $g )"
    if [ "$VERIFY" != "" ]; then
      MSG="$BOLD$1$BOLD is in affiliated group $BOLD$g$BOLD. Had that not been the case"
      EXCLUDED="YES"
    fi
  fi
done

if [ "$EXCLUDED" != "YES" ]; then
  MSG="$BOLD$1$BOLD"
fi

## How much did the user upload this period? 
UP="$( cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $3}')"
if [ "$UP" = "" ]; then
  UP="0"
fi

## Check for other stat sections.
UP2="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $6}')"
if [ "$UP2" != "" ]; then
  UP3="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $9}')"
  if [ "$UP3" != "" ]; then
    UP4="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $12}')"
    if [ "$UP4" != "" ]; then
      UP5="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $15}')"
      if [ "$UP5" != "" ]; then
        UP6="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $18}')"
        if [ "$UP6" != "" ]; then
          UP7="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $21}')"
          if [ "$UP7" != "" ]; then
            UP8="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $24}')"
            if [ "$UP8" != "" ]; then
              UP9="$(cat $USERSLOCATION/$1 | grep -w $DUR | awk -F" " '{print $27}')"
              if [ "$UP9" != "" ]; then
                UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" \+ "$UP5" \+ "$UP6" \+ "$UP7" \+ "$UP8" \+ "$UP9" )"
              else
                UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" \+ "$UP5" \+ "$UP6" \+ "$UP7" \+ "$UP8" )"
              fi
            else
              UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" \+ "$UP5" \+ "$UP6" \+ "$UP7" )"
            fi
          else
            UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" \+ "$UP5" \+ "$UP6" )"
          fi
        else
          UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" \+ "$UP5" )"
        fi
      else
        UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" )"
      fi
    else
      UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" )"
    fi
  else
    UP="$( expr "$UP" \+ "$UP2" )"
  fi
fi

## Split the uploaded number with 1024 to get MB.
UP="$( expr $UP \/ 1024 )"

## Is the user over the limit?
if [ "$UP" -gt "$LIMIT" ]; then
  PASSED="YES"
else
  PASSED="NO"
fi

## Calculate how much under or over the limit the user is.
RATIO="$( expr $UP \- $LIMIT )"

## If the number is negative, remove the - 
RATIO="$( echo $RATIO | tr -d "-")"

## Do we want to show the limit in output?
if [ "$SHOWLIMIT" = "TRUE" ]; then
  SHOWL=" ($LIMIT MB/$DURNAME)"
else
  SHOWL=""
fi

## Say what we want to say, depending on if the user passed the limit or not, and if hes on trial.
case $PASSED in
  YES)
    if [ "$EXCLUDED" = "YES" ]; then
      echo "$SITENAME $MSG, the limit$SHOWL would have been passed with $BOLD$RATIO MB$BOLD to spare."
      exit 0
    else
      echo "$SITENAME $MSG has passed the limit$SHOWL with $BOLD$RATIO MB$BOLD to spare."
      exit 0
    fi
    ;;
  NO)
    if [ "$EXCLUDED" = "YES" ]; then
      echo "$SITENAME $MSG, then $1 would be missing $BOLD$RATIO MB$BOLD to pass$SHOWL."
      exit 0
    else
      echo "$SITENAME $MSG is missing $BOLD$RATIO MB$BOLD to pass$SHOWL."
      exit 0
    fi
    ;;
  *)
    echo "Error in script. User neither passed or failed trial."
    exit 1
    ;;
esac

exit 0
